@@ -1,11 +1,12 @@
 import sys
 import os
+import time
 
 file_path = os.path.abspath(__file__)
 end = file_path.index('mns') + 16
 project_path = file_path[0:end]
 sys.path.append(project_path)
-
+from mns_common.db.MongodbUtil import MongodbUtil
 import requests
 import json
 import pandas as pd
@@ -14,15 +15,20 @@ import datetime
 from loguru import logger
 import mns_common.utils.data_frame_util as data_frame_util
 
+mongodb_util = MongodbUtil('27017')
+fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,"
+          "f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212"),
+fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
+
 # 最大返回条数
 max_number = 5800
 # 最小返回条数
 min_number = 5600
 # 分页条数
-page_number = 100
+PAGE_SIZE = 100
 
 
-def get_stock_page_data(pn, fields, fs, proxies):
+def get_stock_page_data(pn, proxies, page_size):
     """
     获取单页股票数据
     """
@@ -36,7 +42,7 @@ def get_stock_page_data(pn, fields, fs, proxies):
     params = {
         "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
         "pn": str(pn),
-        "pz": "10000",  # 每页最大200条
+        "pz": str(page_size),  # 每页最大200条
         "po": "0",
         "np": "3",
         "ut": "bd1d9ddb04089700cf9c27f6f7426281",
@@ -79,18 +85,18 @@ def get_stock_page_data(pn, fields, fs, proxies):
         return pd.DataFrame()
 
 
-def all_stock_ticker_data_new(fields, fs, proxies) -> pd.DataFrame:
+def all_stock_ticker_data_new(proxies) -> pd.DataFrame:
     """
     使用多线程获取所有股票数据
     """
 
-    per_page = page_number
+    per_page = PAGE_SIZE
     total_pages = (max_number + per_page - 1) // per_page  # 向上取整
 
     # 创建线程池
     with ThreadPoolExecutor(max_workers=10) as executor:
         # 提交任务，获取每页数据
-        futures = [executor.submit(get_stock_page_data, pn, fields, fs, proxies)
+        futures = [executor.submit(get_stock_page_data, pn, proxies, PAGE_SIZE)
                    for pn in range(1, total_pages + 1)]
 
         # 收集结果
@@ -108,21 +114,10 @@ def all_stock_ticker_data_new(fields, fs, proxies) -> pd.DataFrame:
 
 
 def get_real_time_quotes_all_stocks(proxies):
-    fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,"
-              "f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212"),
-    fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
-    # 获取第一页数据
-    page_one_df = get_stock_page_data(1, fields, fs, proxies)
-    # 数据接口正常返回5600以上的数量
-    if page_one_df.shape[0] > min_number:
-        page_one_df = rename_real_time_quotes_df(page_one_df)
-        page_one_df.drop_duplicates('symbol', keep='last', inplace=True)
-        return page_one_df
-    else:
-        page_df = all_stock_ticker_data_new(fields, fs, proxies)
-        page_df = rename_real_time_quotes_df(page_df)
-        page_df.drop_duplicates('symbol', keep='last', inplace=True)
-        return page_df
+    page_df = all_stock_ticker_data_new(proxies)
+    page_df = rename_real_time_quotes_df(page_df)
+    page_df.drop_duplicates('symbol', keep='last', inplace=True)
+    return page_df
 
 
 # 获取所有股票实时行情数据    f33,委比
@@ -298,5 +293,13 @@ def get_sum_north_south_net_buy_amt():
 # 示例调用
 if __name__ == "__main__":
     while True:
-        df = get_real_time_quotes_all_stocks(None)
-        logger.info("涨停数据,{}", 1)
+        ip_proxy_pool = mongodb_util.find_all_data('ip_proxy_pool')
+        if data_frame_util.is_not_empty(ip_proxy_pool):
+            proxy_ip = list(ip_proxy_pool['ip'])[0]
+            proxy = {
+                "https": proxy_ip}
+            df = get_real_time_quotes_all_stocks(proxy)
+            logger.info("涨停数据,{}", 1)
+        else:
+            time.sleep(1)
+            logger.error("ip为空")
