@@ -77,7 +77,9 @@ def kpl_recent_add_new_concept(str_day, before_num, str_now_date):
         'first_plate_name',
         'plate_name_list',
         'most_relative_name',
-        'index_class'
+        'index_class',
+        'sync_str_day',
+        'sync_str_time'
     ]]
 
 
