@@ -148,6 +148,10 @@ HK_COMPANY_INDUSTRY = 'hk_company_industry'
 
 #  公司控股信息 子孙公司 联营公司
 COMPANY_HOLDING_INFO = 'company_holding_info'
+#  公司业务组成
+COMPANY_BUSINESS_INFO = 'company_business_info'
+
+
 #  公司公告信息
 COMPANY_ANNOUNCE_INFO = 'company_announce_info'
 
